@@ -1,4 +1,4 @@
-# Copyright 2020-2020 Exactpro (Exactpro Systems Limited)
+# Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,6 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import logging
 import uuid
 from datetime import datetime
@@ -61,19 +62,6 @@ class EventUtils:
                      body=body,
                      attached_message_ids=attached_message_ids)
 
-    @staticmethod
-    def create_verification_event(name: str, comparison_entry: ComparisonEntry, id: EventID = None,
-                                  parent_id: EventID = None, body: bytes = None,
-                                  attached_message_ids: [MessageID] = None) -> Event:
-        status = EventStatus.FAILED if ComparatorUtils.get_status_type(
-            comparison_entry) == ComparisonEntryStatus.FAILED else EventStatus.SUCCESS
-        return EventUtils.create_event(name=name,
-                                       id=id,
-                                       parent_id=parent_id,
-                                       status=status,
-                                       body=body,
-                                       attached_message_ids=attached_message_ids)
-
 
 class MessageUtils:
 
@@ -83,9 +71,19 @@ class MessageUtils:
 
     @staticmethod
     def str_message_id(message: Message) -> str:
-        res = str(message.metadata.id.connection_id.session_alias) + ':'
-        res += str(Direction.Name(message.metadata.id.direction)) + ':'
-        res += str(message.metadata.id.sequence)
+        res = ""
+        try:
+            res += str(message.metadata.id.connection_id.session_alias) + ':'
+        except AttributeError:
+            res += "None:"
+        try:
+            res += str(Direction.Name(message.metadata.id.direction)) + ':'
+        except AttributeError:
+            res += "None:"
+        try:
+            res += str(message.metadata.id.sequence)
+        except AttributeError:
+            res += "None"
         return res
 
 
@@ -121,14 +119,14 @@ class ComparatorUtils:
 class MessageComponent:
 
     def __init__(self, message: str) -> None:
-        self.type = "message"
+        self.type = 'message'
         self.data = message
 
 
 class TableComponent:
 
     def __init__(self, column_names: list) -> None:
-        self.type = "table"
+        self.type = 'table'
         self.rows = []
         self.__column_names = column_names
 
@@ -140,7 +138,7 @@ class TableComponent:
 class VerificationComponent:
 
     def __init__(self, comparison_entry: ComparisonEntry) -> None:
-        self.type = "verification"
+        self.type = 'verification'
         self.fields = {field_name: VerificationComponent.VerificationEntry(comparison_entry.fields[field_name])
                        for field_name in comparison_entry.fields.keys()}
         self.status = EventStatus.FAILED if ComparatorUtils.get_status_type(
